Class: permissible_value - LinkML Model

# Class: permissible_value

a permissible value, accompanied by intended text and an optional mapping to a concept URI

URI: linkml:PermissibleValue

## Uses Mixin

- mixin: Extensible - mixin for classes that support extension
- mixin: Annotatable - mixin for classes that support annotations
- mixin: CommonMetadata - Generic metadata shared across definitions

## Referenced by Class

- PermissibleValue permissible_value➞is_a 0..1 PermissibleValue
- PermissibleValue permissible_value➞mixins 0..* PermissibleValue
- EnumDefinition permissible_values 0..* PermissibleValue

## Attributes

### Own

- text 1..1
  - Range: String
- description 0..1
  - Description: a description of the element's purpose and use
  - Range: String
  - in subsets: (owl)
- meaning 0..1
  - Description: the value meaning (in the 11179 sense) of a permissible value
  - Range: Uriorcurie
- permissible_value➞is_a 0..1
  - Range: PermissibleValue
- permissible_value➞mixins 0..*
  - Range: PermissibleValue

### Mixed in from extensible:

- extensions 0..*
  - Description: a tag/text tuple attached to an arbitrary element
  - Range: Extension

### Mixed in from annotatable:

- annotations 0..*
  - Description: a collection of tag/text tuples with the semantics of OWL Annotation
  - Range: Annotation

### Mixed in from common_metadata:

- alt_descriptions 0..*
  - Range: AltDescription

### Mixed in from common_metadata:

- deprecated 0..1
  - Description: Description of why and when this element will no longer be used
  - Range: String

### Mixed in from common_metadata:

- todos 0..*
  - Description: Outstanding issue that needs resolution
  - Range: String

### Mixed in from common_metadata:

- notes 0..*
  - Description: editorial notes about an element intended for internal consumption
  - Range: String
  - in subsets: (owl)

### Mixed in from common_metadata:

- comments 0..*
  - Description: notes and comments about an element intended for external consumption
  - Range: String
  - in subsets: (owl)

### Mixed in from common_metadata:

- examples 0..*
  - Description: example usages of an element
  - Range: Example
  - in subsets: (owl)

### Mixed in from common_metadata:

- in_subset 0..*
  - Description: used to indicate membership of a term in a defined subset of terms used for a particular domain or application (e.g. the translator_minimal subset holding the minimal set of predicates used in a translator knowledge graph)
  - Range: SubsetDefinition

### Mixed in from common_metadata:

- from_schema 0..1
  - Description: id of the schema that defined the element
  - Range: Uri

### Mixed in from common_metadata:

- imported_from 0..1
  - Description: the imports entry that this element was derived from. Empty means primary source
  - Range: String

### Mixed in from common_metadata:

- see_also 0..*
  - Description: a reference
  - Range: Uriorcurie
  - in subsets: (owl)

### Mixed in from common_metadata:

- deprecated element has exact replacement 0..1
  - Description: When an element is deprecated, it can be automatically replaced by this uri or curie
  - Range: Uriorcurie

### Mixed in from common_metadata:

- deprecated element has possible replacement 0..1
  - Description: When an element is deprecated, it can be potentially replaced by this uri or curie
  - Range: Uriorcurie